@@ -1,21 +1,21 @@
-id = "5fd44d9165c1083e35c615f1eb95979a07e0e3d0"
-date = "2015-05-22 20:41:05 +0000"
-branch = "None"
-tag = "glue-release-1-48"
+id = "3dc971a085afdbf06b44fb463ed08036270bf377"
+date = "2015-07-22 20:37:02 +0000"
+branch = "glue-1-49-branch"
+tag = "glue-release-1-49"
 if tag == "None":
     tag = None
 author = "Ryan Fisher <ryan.fisher@ligo.org>"
 builder = "Ryan Fisher <ryan.fisher@ligo.org>"
 committer = "Ryan Fisher <ryan.fisher@ligo.org>"
-status = "CLEAN: All modifications committed"
+status = "UNCLEAN: Modified working tree"
 version = id
-verbose_msg = """Branch: None
-Tag: glue-release-1-48
-Id: 5fd44d9165c1083e35c615f1eb95979a07e0e3d0
+verbose_msg = """Branch: glue-1-49-branch
+Tag: glue-release-1-49
+Id: 3dc971a085afdbf06b44fb463ed08036270bf377
 
 Builder: Ryan Fisher <ryan.fisher@ligo.org>
-Build date: 2015-05-22 20:42:30 +0000
-Repository status: CLEAN: All modifications committed"""
+Build date: 2015-07-23 22:58:03 +0000
+Repository status: UNCLEAN: Modified working tree"""
 
 import warnings
 
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "5fd44d9165c1083e35c615f1eb95979a07e0e3d0":
+    if foreign_id == "3dc971a085afdbf06b44fb463ed08036270bf377":
         return
-    msg = "Program id (5fd44d9165c1083e35c615f1eb95979a07e0e3d0) does not match given id (%s)." % foreign_id
+    msg = "Program id (3dc971a085afdbf06b44fb463ed08036270bf377) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
