@@ -1,4 +1,4 @@
-# Copyright (C) 2006--2009,2012--2014  Kipp Cannon
+# Copyright (C) 2006--2009,2012--2015  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -303,8 +303,7 @@ def use_in(ContentHandler):
 	>>> def MyContentHandler(ligolw.LIGOLWContentHandler):
 	...	pass
 	...
-	>>> from glue.ligolw import param
-	>>> param.use_in(MyContentHandler)
+	>>> use_in(MyContentHandler)
 	"""
 	def startParam(self, parent, attrs):
 		return Param(attrs)
