@@ -33,13 +33,6 @@
 #include <string.h>
 #include <tokenizer.h>
 
-/* Gain access to 64-bit addressing where possible
- * http://www.python.org/dev/peps/pep-0353/#conversion-guidelines */
-#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
-typedef int Py_ssize_t;
-#define PY_SSIZE_T_MAX INT_MAX
-#define PY_SSIZE_T_MIN INT_MIN
-#endif
 
 /*
  * ============================================================================
